_antonyms = {
    "abilitate": "incapacitate",
    "anormal": "normal",
    "aboli": "a stabili",
    "absență": "prezenţă",
    "absent": "prezent",
    "viitor": "retrospectiv",
    "absolut": "relativ",
    "abține": "act",
    "abstract": "beton",
    "abundenţă": "raritate",
    "abundent": "rar",
    "accept": "respinge",
    "admite": "nega",
    "acceptabil": "de netrecut",
    "acceptare": "respingere",
    "accesibil": "inaccesibil",
    "precis": "ambiguu",
    "recunoscut": "nerecunoscut",
    "cunoștință": "străin",
    "act": "abține",
    "acțiune": "inacțiune",
    "activ": "liniște",
    "existent": "inexistent",
    "zgomotos": "liniște",
    "activitate": "inactivitate",
    "real": "ireal",
    "adăuga": "scădea",
    "plus": "scădere",
    "adecvat": "neadecvat",
    "adjectiv": "substantiv",
    "admisibil": "inadmisibil",
    "adult": "juvenil",
    "avans": "retrage",
    "înainte": "înapoi",
    "față": "spate",
    "a-și schimba direcția": "înapoi",
    "avantaj": "dezavantaj",
    "afirmare": "inversare",
    "afirmativ": "negativ",
    "neutru": "feminin",
    "la pupă": "proră",
    "vârstă": "întineri",
    "în vârstă de": "tineri",
    "agitaţie": "calm",
    "de acord": "dezacord",
    "agreabil": "dezagreabil",
    "acord": "dezacord",
    "modificată": "neschimbat",
    "alterna": "opus",
    "amator": "profesional",
    "ambiguu": "precis",
    "amical": "ostil",
    "prietenos": "neprietenos",
    "amfibiu": "terestru",
    "anal": "oral",
    "analog": "omolog",
    "analiză": "sinteză",
    "analitic": "sintetic",
    "strămoş": "descendent",
    "unghiular": "rotunjit",
    "anima": "neînsufleţit",
    "răspuns": "întrebare",
    "antagonic": "sinergică",
    "antecedente": "ulterior",
    "anterior": "posterior",
    "antiseptic": "septic",
    "aspect": "dispariție",
    "apreciere": "depreciere",
    "aprobare": "dezaprobare",
    "aproba": "dezaproba",
    "acvatic": "amfibiu",
    "terestru": "amfibiu",
    "apos": "de foc",
    "braţ": "dezarma",
    "armat": "neînarmat",
    "ajunge": "părăsi",
    "urca": "coborî",
    "ascensiune": "coborâre",
    "adormit": "treaz",
    "consimțământ": "disidență",
    "asimetrie": "simetrie",
    "ateism": "teismului",
    "atașa": "desprinde",
    "atac": "apăra",
    "urmări în justiție": "apăra",
    "atenţie": "neatenţie",
    "atracţie": "repulsie",
    "perceptibil": "imperceptibil",
    "augmentare": "diminuare",
    "mătuşă": "unchi",
    "autorizat": "neautorizat",
    "automat": "manual",
    "evita": "confrunta",
    "treaz": "adormit",
    "înapoi": "redirecţiona",
    "retrage": "depozit",
    "spate": "cap",
    "fundal": "prim plan",
    "verso": "avers",
    "rău": "virtuos",
    "proastă calitate": "bunătate",
    "echilibrat": "dezechilibrat",
    "urs": "taur",
    "frumoasa": "urât",
    "frumuseţe": "urâţenie",
    "începe": "sfârşit",
    "început": "mijloc",
    "din timp": "târziu",
    "credință": "necredinţă",
    "îndoire": "îndrepta",
    "benign": "maligne",
    "mare": "mic",
    "naștere": "moarte",
    "bisexuat": "homosexual",
    "negru": "alb",
    "binecuvânta": "blestem",
    "binecuvântat": "blestemat",
    "fără vlagă": "sângeros",
    "sângeros": "fără vlagă",
    "estompa": "concentra",
    "a fierbe": "îngheţa",
    "îndrăzneţ": "timid",
    "îndrăzneală": "timiditate",
    "împrumuta": "a împrumuta",
    "debitor": "creditor",
    "fund": "top",
    "legat": "nelegat",
    "băiat": "fată",
    "boicota": "patrona",
    "pauză": "reparație",
    "casant": "incasabil",
    "lumina": "întuneca",
    "uşura": "dificultate",
    "spart": "neîntrerupt",
    "frate": "soră",
    "taur": "urs",
    "ocupat": "neocupat",
    "muncă": "inactiv",
    "a cumpara": "vinde",
    "calm": "agitaţie",
    "capabil": "incapabil",
    "capacitate": "incapacitate",
    "bani gheata": "credit",
    "debit": "credit",
    "centru": "stânga",
    "cerebral": "emoţional",
    "certitudine": "incertitudine",
    "schimbare": "stau",
    "pleca": "stau",
    "mișcare": "stau",
    "schimbător": "egal",
    "schimbat": "neschimbat",
    "încărca": "descărcare",
    "înrola": "descărcare",
    "ieftin": "scump",
    "ridica moralul": "plânge",
    "bine dispus": "deprimant",
    "copil": "mamă",
    "civil": "militar",
    "revendicare": "pierdut",
    "claritate": "opacitate",
    "proeminenţă": "obscuritate",
    "transparenţă": "opacitate",
    "curat": "necurat",
    "cler": "laici",
    "cleric": "laic",
    "închide": "deschis",
    "închis": "deschis",
    "apropiere": "sinceritate",
    "de coastă": "interior",
    "coerent": "incoerent",
    "rece": "fierbinte",
    "colateral": "descinzând direct",
    "comedie": "tragedie",
    "confort": "disconfort",
    "comun": "extraordinar",
    "compatibil": "incompatibil",
    "competență": "incompetenţă",
    "competent": "incompetent",
    "competiție": "cooperare",
    "plânge": "ridica moralul",
    "deplinătate": "incompletitudine",
    "complex": "simplu",
    "compus": "simplu",
    "conforme": "sfidător",
    "complica": "simplifica",
    "concav": "convex",
    "vanitate": "umilinţă",
    "mândrie": "umilinţă",
    "concentraţie": "distribuire",
    "concentric": "excentric",
    "concepţie": "neînțelegere",
    "îngrijorat": "indiferent",
    "beton": "abstract",
    "confirmat": "neconfirmat",
    "confrunta": "evita",
    "conjunctiv": "disjunctiv",
    "conectați": "deconecta",
    "conectat": "neconectat",
    "constiinta": "inconştienţă",
    "conservator": "liberal",
    "conserva": "deşeuri",
    "grijuliu": "nechibzuit",
    "consistență": "incoerență",
    "consoană": "vocală",
    "evident": "inobservabil",
    "constituţional": "neconstituțional",
    "a consuma": "abține",
    "conţinut": "nemulţumire",
    "continuu": "discontinuu",
    "continuare": "întrerupere",
    "continua": "întrerupe",
    "continuitate": "discontinuitate",
    "contracta": "extinde",
    "contractat": "extins",
    "contracție": "expansiune",
    "convenabil": "incomod",
    "convenţional": "neconvențional",
    "converge": "diverge",
    "convergenţă": "divergenţă",
    "convergent": "divergent",
    "convex": "concav",
    "convins": "neconvins",
    "misto": "căldură",
    "cooperare": "competiție",
    "cosmopolit": "provincial",
    "curaj": "laşitate",
    "acoperi": "descoperi",
    "ascuns": "deschis",
    "laşitate": "curaj",
    "credit": "debit",
    "creditor": "debitor",
    "a critica": "laudă",
    "strigăt": "şoaptă",
    "vindecabil": "incurabil",
    "blestem": "binecuvânta",
    "blestemat": "binecuvântat",
    "curb": "drept",
    "a taia": "netăiat",
    "pericol": "siguranță",
    "periculos": "sigur",
    "întuneric": "lumină",
    "întuneca": "uşura",
    "greutate": "lumină",
    "fiică": "fiu",
    "zi": "noapte",
    "surd": "auz",
    "moarte": "născând",
    "decenţă": "indecenţă",
    "decent": "indecent",
    "cu frunze căzătoare": "vesnic verde",
    "decizie": "nehotărâre",
    "decisiv": "nehotărât",
    "declin": "ceară",
    "scădea": "adăuga",
    "scăzut": "a crescut",
    "decrementare": "creştere",
    "înfrângere": "victorie",
    "apăra": "urmări în justiție",
    "pârât": "reclamant",
    "apărare": "urmarire penala",
    "defensivă": "ofensator",
    "sfidător": "conforme",
    "deficit": "conduce",
    "definit": "nedefinit",
    "deflaţie": "umflare",
    "întârziere": "te grabesti",
    "persista": "te grabesti",
    "cerere": "livra",
    "nega": "admite",
    "respinge": "accept",
    "dependent": "independent",
    "depozit": "retrage",
    "depreciere": "apreciere",
    "deprimant": "bine dispus",
    "coborî": "urca",
    "descendent": "strămoş",
    "coborâre": "ascensiune",
    "descriptiv": "prescriptiv",
    "de dorit": "indezirabil",
    "disperare": "speranţă",
    "disperată": "speranţă",
    "desperare": "speranţă",
    "distrus": "conservat",
    "desprinde": "atașa",
    "transfer": "evoluţie",
    "diferi": "egal",
    "inegal": "egal",
    "diferență": "monotonie",
    "dificil": "uşor",
    "neliniștit": "uşor",
    "dificultate": "uşura",
    "harnic": "neglijent",
    "diluare": "concentraţie",
    "distribuire": "concentraţie",
    "diminuare": "augmentare",
    "murdar": "curat",
    "necurat": "curat",
    "dezactivați": "permite",
    "dezavantaj": "avantaj",
    "dezacord": "acord",
    "dezagreabil": "agreabil",
    "dispariție": "aspect",
    "dezaprobare": "aprobare",
    "dezaproba": "aproba",
    "dezarma": "braţ",
    "descărcare": "înrola",
    "repudia": "revendicare",
    "pierdut": "găsite",
    "disconfort": "confort",
    "deconecta": "conectați",
    "nemulţumire": "satisfacţie",
    "întrerupere": "continuare",
    "întrerupe": "continua",
    "discontinuitate": "continuitate",
    "discontinuu": "continuu",
    "descuraja": "convinge",
    "descurajare": "încurajare",
    "decupla": "angaja",
    "necinstit": "sincer",
    "necinste": "onestitate",
    "dezonoare": "reputaţie",
    "dezinfecta": "infecta",
    "dezintegra": "integra",
    "disjunctiv": "conjunctiv",
    "nu-i plăcea": "simpatie",
    "deplasa": "depune",
    "nesupunere": "ascultare",
    "neascultător": "ascultător",
    "nu se supune": "asculta",
    "tulburare": "ordin",
    "dezordonat": "ordonat",
    "dezorganizat": "organizat",
    "neorganizat": "organizat",
    "nemulțumit": "mulţumit",
    "demonstra falsitatea": "dovedi",
    "descalifica": "califica",
    "infamant": "cu reputație bună",
    "lipsă de respect": "respect",
    "nerespectuos": "respectuos",
    "disidență": "consimțământ",
    "deserviciu": "serviciu",
    "diferit": "asemănător",
    "disonanţă": "armonie",
    "distală": "proxim",
    "îndepărtat": "închide",
    "deschis": "ascuns",
    "neîncredere": "încredere",
    "diurn": "nocturn",
    "diverge": "converge",
    "divergenţă": "convergenţă",
    "divergent": "convergent",
    "divide": "uni",
    "unul câte unul": "multiplica",
    "împărțit": "unit",
    "divizibil": "indivizibil",
    "intern": "extern",
    "nativ": "străin",
    "dominant": "subordonat",
    "inactiv": "muncă",
    "dispărut": "existent",
    "pasiv": "activ",
    "liniște": "zgomotos",
    "dubla": "singur",
    "multiplu": "singur",
    "porumbel": "şoim",
    "dramatic": "liric",
    "uscat": "umed",
    "acru": "îndulci",
    "datorat": "nedrept",
    "plictisitor": "ascuţi",
    "aplatiza": "ascuţi",
    "pământesc": "ceresc",
    "uşor": "neliniștit",
    "reflux": "maree",
    "excentric": "concentric",
    "educat": "necultivat",
    "efectiv": "ineficace",
    "eficienţă": "ineficacitate",
    "eficient": "ineficace",
    "ieşire": "pătrundere",
    "elastic": "inelastică",
    "eligibil": "neeligibile",
    "emoţional": "cerebral",
    "empiric": "teoretic",
    "goliciune": "plenitudine",
    "gol": "solid",
    "subţire": "se îngroșa",
    "permite": "interzis",
    "a incuraja": "descuraja",
    "încurajare": "descurajare",
    "sfârşit": "început",
    "final": "proxim",
    "mijloc": "din timp",
    "endemic": "cosmopolit",
    "provincial": "cosmopolit",
    "energic": "letargic",
    "impune": "scuti",
    "angaja": "decupla",
    "se bucura": "suferi",
    "introduce": "ieșire",
    "egal": "schimbător",
    "egalitate": "inegalitate",
    "ecuatorial": "polar",
    "echitabil": "nedrept",
    "echivoc": "neechivoc",
    "şterge": "record",
    "a stabili": "aboli",
    "bogat în evenimente": "fără evenimente importante",
    "vesnic verde": "cu frunze căzătoare",
    "evoluţie": "transfer",
    "excludere": "includere",
    "scuti": "impune",
    "exala": "inhala",
    "ieșire": "introduce",
    "extinde": "contracta",
    "extins": "contractat",
    "expansiune": "contracție",
    "așteptat": "neașteptat",
    "scump": "ieftin",
    "cu experienta": "lipsit de experiență",
    "export": "import",
    "expres": "local",
    "general": "specific",
    "naţional": "internaţional",
    "extensie": "flexiune",
    "exterior": "interior",
    "extern": "intern",
    "a stinge": "aprinde",
    "extramural": "intramurale",
    "extraordinar": "comun",
    "extrinsecă": "intrinsec",
    "în lipsa": "trecere",
    "alergare": "permanent",
    "eșec": "succes",
    "credincios": "necredincios",
    "cădea": "creştere",
    "a stabilit": "creştere",
    "supus greșelii": "infailibil",
    "cădere": "în creștere",
    "falsitate": "adevăr",
    "faimă": "infamie",
    "familiar": "necunoscut",
    "extravagant": "simplu",
    "gras": "subţire",
    "deplin": "gol",
    "gros": "subţire",
    "se îngroșa": "subţire",
    "tată": "mamă",
    "faună": "floră",
    "favorabil": "nefavorabil",
    "federal": "unitar",
    "femeie": "masculin",
    "feminin": "neutru",
    "feminitate": "masculinitate",
    "fertil": "steril",
    "fidelitate": "infidelitate",
    "figura": "sol",
    "completati": "gol",
    "găsi": "pierde",
    "finalizarea": "start",
    "stop": "start",
    "finit": "infinit",
    "foc": "închiriere",
    "flexiune": "extensie",
    "pluti": "chiuvetă",
    "sursă": "chiuvetă",
    "floră": "faună",
    "concentra": "estompa",
    "duşman": "prieten",
    "plia": "desfășura",
    "urma": "preceda",
    "a reusi": "preceda",
    "adept": "lider",
    "nebunie": "sănătate psihică",
    "prostesc": "înţelept",
    "picior": "cap",
    "coadă": "cap",
    "interzis": "permite",
    "proră": "la pupă",
    "prim plan": "fundal",
    "străin": "cunoștință",
    "a uita": "tine minte",
    "iertător": "neiertat",
    "formalism": "imitaţie",
    "norocos": "ghinionist",
    "redirecţiona": "verso",
    "avers": "verso",
    "fault": "echitabil",
    "nedrept": "datorat",
    "găsite": "pierdut",
    "fratern": "identic",
    "îngheţa": "a fierbe",
    "frecvent": "rar",
    "des": "rar",
    "prieten": "duşman",
    "cap": "coadă",
    "plenitudine": "goliciune",
    "funcţional": "organic",
    "anorganic": "organic",
    "câştig": "pierderi",
    "gazos": "solid",
    "aduna": "răspândire",
    "generalitate": "particularitate",
    "generos": "zgârcit",
    "fată": "băiat",
    "bun": "rău",
    "bunătate": "proastă calitate",
    "treptat": "brusc",
    "recunoscător": "nerecunoscător",
    "mai mare": "mai puțin",
    "verde": "copt",
    "brut": "net",
    "sol": "figura",
    "vinovăţie": "nevinovăţie",
    "vinovat": "nevinovat",
    "fericit": "nefericit",
    "fericire": "nefericire",
    "duritate": "moliciune",
    "intensitate": "moliciune",
    "acuitate": "moliciune",
    "armonie": "disonanţă",
    "ură": "dragoste",
    "odios": "amabil",
    "şoim": "porumbel",
    "sănătos": "nesănătos",
    "auz": "surd",
    "căldură": "misto",
    "ceresc": "pământesc",
    "eterogenitate": "omogenitate",
    "ascunde": "spectacol",
    "închiriere": "foc",
    "lovit": "domnișoară",
    "sfânt": "nesfânt",
    "omogenitate": "eterogenitate",
    "omolog": "analog",
    "homosexual": "bisexuat",
    "sincer": "necinstit",
    "onestitate": "necinste",
    "onora": "dezonoare",
    "speranţă": "desperare",
    "plin de speranță": "fara speranta",
    "fara speranta": "plin de speranță",
    "orizontală": "vertical",
    "ostil": "prietenos",
    "neprietenos": "prietenos",
    "fierbinte": "rece",
    "umil": "mândru",
    "umilinţă": "mândrie",
    "flămând": "însetat",
    "identic": "fratern",
    "de foc": "apos",
    "aprinde": "a stinge",
    "ignora": "înștiințare",
    "ilegal": "legal",
    "nelegalitate": "legalitate",
    "ilizibil": "lizibil",
    "ilogic": "logic",
    "imitaţie": "formalism",
    "imaterial": "material",
    "imaturitate": "maturitate",
    "nemasurata": "măsurabil",
    "imoral": "morală",
    "imoralitate": "moralitate",
    "nemuritor": "muritor",
    "nemurire": "mortalitate",
    "imuabil": "mutabil",
    "imparţialitate": "părtinire",
    "de netrecut": "acceptabil",
    "nerăbdare": "răbdare",
    "nerăbdător": "rabdator",
    "imperceptibil": "perceptibil",
    "imperfecţiune": "perfecţiune",
    "impermeabil": "permeabil",
    "de nepermis": "permisibil",
    "impersonal": "personal",
    "nepoliticos": "politicos",
    "import": "export",
    "important": "neimportant",
    "imposibilitate": "posibilitate",
    "impotent": "puternic",
    "improbabil": "probabil",
    "îmbunătățit": "neamenajat",
    "îmbunătăţire": "declin",
    "imprudent": "prudent",
    "impuritate": "puritate",
    "incapacitate": "capacitate",
    "inaccesibil": "accesibil",
    "inexact": "precis",
    "inacțiune": "acțiune",
    "inactivitate": "activitate",
    "neadecvat": "adecvat",
    "inadmisibil": "admisibil",
    "neînsufleţit": "anima",
    "neatenţie": "atenţie",
    "abia auzit": "perceptibil",
    "incapabil": "capabil",
    "înclinat": "orizontală",
    "vertical": "orizontală",
    "includere": "excludere",
    "incoerent": "coerent",
    "incompatibil": "compatibil",
    "incompetenţă": "competență",
    "incompetent": "competent",
    "incompletitudine": "deplinătate",
    "nechibzuit": "grijuliu",
    "incoerență": "consistență",
    "inobservabil": "evident",
    "incomod": "convenabil",
    "crește": "scădea",
    "a crescut": "scăzut",
    "creştere": "a stabilit",
    "incurabil": "vindecabil",
    "indecenţă": "decenţă",
    "indecent": "decent",
    "nehotărâre": "decizie",
    "nehotărât": "decisiv",
    "independent": "dependent",
    "indivizibil": "divizibil",
    "de interior": "în aer liber",
    "ineficace": "eficient",
    "ineficacitate": "eficienţă",
    "inelastică": "elastic",
    "neeligibile": "eligibil",
    "inegalitate": "egalitate",
    "inechitabil": "echitabil",
    "lipsit de experiență": "cu experienta",
    "infailibil": "supus greșelii",
    "infamie": "faimă",
    "infecta": "dezinfecta",
    "inferior": "a ridica",
    "inferioritate": "superioritate",
    "infidelitate": "fidelitate",
    "infinit": "finit",
    "umflare": "deflaţie",
    "informat": "neinformat",
    "rar": "abundent",
    "pătrundere": "ieşire",
    "locuit": "nelocuit",
    "inhala": "exala",
    "nedreptate": "justiţie",
    "interior": "exterior",
    "nevinovăţie": "vinovăţie",
    "nevinovat": "vinovat",
    "inofensiv": "nociv",
    "inoperant": "operativ",
    "nebun": "normal",
    "nesiguranță": "securitate",
    "inconsistență": "semnificaţie",
    "nesemnificativ": "semnificativ",
    "insolubil": "solubil",
    "insolvabilitate": "solvabilitate",
    "insolvabil": "solvent",
    "instabilitate": "stabilitate",
    "instrumental": "vocal",
    "insuficienţă": "suficienta",
    "insuficient": "suficient",
    "integra": "dezintegra",
    "integrare": "segregare",
    "inteligență": "prostie",
    "inteligibil": "ininteligibil",
    "destinate": "neintenționate",
    "intentionat": "fara intentie",
    "interesat": "dezinteresați",
    "interesant": "neinteresant",
    "intermediar": "terminal",
    "internaţional": "naţional",
    "local": "general",
    "intoleranţă": "toleranţă",
    "intolerant": "tolerant",
    "intratabil": "maleabil",
    "intramurale": "extramural",
    "intrinsec": "extrinsecă",
    "invizibilitate": "vizibilitate",
    "invizibil": "vizibil",
    "involuntar": "voluntar",
    "iraţional": "raţional",
    "neregulat": "regulat",
    "neregularitate": "regularitate",
    "irelevant": "relevant",
    "iresponsabil": "responsabil",
    "ireverențios": "respectuos",
    "problema": "rechemare",
    "bucurie": "întristare",
    "vesel": "trist",
    "junior": "senior",
    "justiţie": "nedreptate",
    "juvenil": "adult",
    "țăran irlandez": "țăran irlandez",
    "drăguț": "aspru",
    "rege": "regină",
    "laici": "cler",
    "târziu": "din timp",
    "a rade": "strigăt",
    "legal": "ilegal",
    "lax": "încordat",
    "relaxat": "încordat",
    "laic": "religios",
    "conduce": "deficit",
    "lider": "adept",
    "părăsi": "ajunge",
    "stânga": "centru",
    "legalitate": "nelegalitate",
    "legaliza": "haiduc",
    "lizibil": "ilizibil",
    "a împrumuta": "împrumuta",
    "prelungi": "scurta",
    "mai puțin": "mai mare",
    "letargic": "energic",
    "nivel": "a ridica",
    "liberal": "conservator",
    "minciună": "stand",
    "randament": "stand",
    "ușoară": "întuneric",
    "lumină": "greutate",
    "simpatie": "nu-i plăcea",
    "limitat": "nelimitat",
    "descinzând direct": "colateral",
    "lichid": "gazos",
    "solid": "gol",
    "specific": "general",
    "locație": "studio",
    "blocare": "descuia",
    "depune": "deplasa",
    "logic": "ilogic",
    "lung": "mic de statura",
    "înalt": "mic de statura",
    "slăbi": "înțepeni",
    "pierde": "găsi",
    "pierderi": "câştig",
    "amabil": "odios",
    "dragoste": "ură",
    "liric": "dramatic",
    "major": "minor",
    "majoritate": "minoritate",
    "face": "pauză",
    "reparație": "pauză",
    "masculin": "feminin",
    "bârfi": "benign",
    "maligne": "benign",
    "manual": "automat",
    "marcat": "nemarcate",
    "căsătorit": "necăsătorit",
    "masculinitate": "feminitate",
    "masca": "demasca",
    "material": "imaterial",
    "matern": "patern",
    "maturitate": "imaturitate",
    "maxim": "minim",
    "măsurabil": "nemasurata",
    "mental": "fizic",
    "milostiv": "nemilos",
    "nemilos": "milostiv",
    "militar": "civil",
    "minte": "a uita",
    "tine minte": "a uita",
    "minim": "maxim",
    "minor": "major",
    "minoritate": "majoritate",
    "neînțelegere": "concepţie",
    "domnișoară": "lovit",
    "molar": "molecular",
    "molecular": "molar",
    "morală": "imoral",
    "moralitate": "imoralitate",
    "muritor": "nemuritor",
    "mortalitate": "nemurire",
    "mamă": "copil",
    "multiplica": "unul câte unul",
    "uni": "divide",
    "mutabil": "imuabil",
    "nadir": "zenit",
    "îngust": "largi",
    "născând": "moarte",
    "negativ": "neutru",
    "neglijent": "harnic",
    "nepot": "nepoată",
    "net": "brut",
    "nepoată": "nepot",
    "noapte": "zi",
    "nocturn": "diurn",
    "nominal": "real",
    "ireal": "real",
    "inexistent": "existent",
    "normal": "nebun",
    "înștiințare": "ignora",
    "nociv": "inofensiv",
    "numeric": "verbal",
    "ascultare": "nesupunere",
    "ascultător": "neascultător",
    "asculta": "nu se supune",
    "obiectiv": "subiectiv",
    "obligatoriu": "facultativ",
    "oblic": "perpendicular",
    "obscuritate": "proeminenţă",
    "opacitate": "transparenţă",
    "delict": "apărare",
    "urmarire penala": "apărare",
    "ofensator": "defensivă",
    "oficial": "neoficial",
    "sinceritate": "apropiere",
    "operativ": "inoperant",
    "opus": "alterna",
    "optimism": "pesimism",
    "optimist": "pesimist",
    "facultativ": "obligatoriu",
    "oral": "anal",
    "ordin": "tulburare",
    "ordonat": "dezordonat",
    "organic": "anorganic",
    "organizat": "neorganizat",
    "ortodox": "neortodox",
    "în aer liber": "de interior",
    "haiduc": "legaliza",
    "exagera": "subestima",
    "deasupra": "suprafaţă",
    "ambalaj": "despacheta",
    "dureros": "nedureros",
    "nedureros": "dureros",
    "paralel": "oblic",
    "perpendicular": "oblic",
    "părtinire": "imparţialitate",
    "particularitate": "generalitate",
    "parţial": "în întregime",
    "trecere": "alergare",
    "permanent": "alergare",
    "trecut": "viitor",
    "prezent": "absent",
    "patern": "matern",
    "răbdare": "nerăbdare",
    "rabdator": "nerăbdător",
    "patrona": "boicota",
    "pace": "război",
    "penalizare": "recompensă",
    "perfecţiune": "imperfecţiune",
    "permeabil": "impermeabil",
    "permisibil": "de nepermis",
    "permisiv": "preventiv",
    "personal": "impersonal",
    "convinge": "descuraja",
    "pesimism": "optimism",
    "pesimist": "optimist",
    "fizic": "mental",
    "simplu": "compus",
    "reclamant": "pârât",
    "placut": "neplăcut",
    "mulţumit": "nemulțumit",
    "plural": "singular",
    "polar": "ecuatorial",
    "politicos": "nepoliticos",
    "popular": "nepopular",
    "porozitate": "soliditate",
    "posibilitate": "imposibilitate",
    "posterior": "anterior",
    "puternic": "fără putere",
    "potenţial": "real",
    "sărăcie": "bogatie",
    "fără putere": "puternic",
    "laudă": "a critica",
    "preceda": "a reusi",
    "precedent": "reușind",
    "prefix": "sufix",
    "preparare": "rezoluţie",
    "pregătit": "nepregătit",
    "prescriptiv": "descriptiv",
    "prezenţă": "absență",
    "conservat": "distrus",
    "preventiv": "permisiv",
    "primar": "secundar",
    "privat": "public",
    "probabil": "improbabil",
    "productiv": "neproductiv",
    "profan": "sacru",
    "profesional": "amator",
    "progres": "regres",
    "progresiv": "regresiv",
    "protejat": "neprotejat",
    "mândru": "umil",
    "dovedi": "demonstra falsitatea",
    "proxim": "final",
    "prudent": "imprudent",
    "public": "privat",
    "publicat": "nepublicat",
    "trage": "apăsaţi",
    "punctualitate": "încetineală",
    "epurare": "reabilita",
    "puritate": "impuritate",
    "apăsaţi": "trage",
    "califica": "descalifica",
    "regină": "rege",
    "întrebare": "răspuns",
    "discutabil": "necontestat",
    "repede": "încet",
    "a ridica": "inferior",
    "raţional": "iraţional",
    "realist": "nerealiste",
    "reasigura": "face griji",
    "rechemare": "problema",
    "record": "şterge",
    "refuza": "accept",
    "regres": "progres",
    "regresiv": "progresiv",
    "regulat": "neregulat",
    "regularitate": "neregularitate",
    "reglementate": "nereglementat",
    "reabilita": "epurare",
    "respingere": "acceptare",
    "întineri": "vârstă",
    "legate de": "fără legătură",
    "relativ": "absolut",
    "relevant": "irelevant",
    "de încredere": "nedemn de încredere",
    "religios": "laic",
    "repulsie": "atracţie",
    "cu reputație bună": "infamant",
    "reputaţie": "dezonoare",
    "a rezista": "predare",
    "rezoluţie": "preparare",
    "respect": "lipsă de respect",
    "respectuos": "ireverențios",
    "responsabil": "iresponsabil",
    "reținut": "nestăpânit",
    "restrâns": "fără restricții",
    "retrospectiv": "viitor",
    "inversare": "afirmare",
    "recompensă": "penalizare",
    "călătorie": "mers pe jos",
    "copt": "verde",
    "în creștere": "cădere",
    "rotor": "stator",
    "rugozitate": "finete",
    "rundă": "pătrat",
    "rotunjit": "unghiular",
    "rural": "urban",
    "te grabesti": "persista",
    "sacru": "profan",
    "trist": "vesel",
    "tristeţe": "fericire",
    "nefericire": "fericire",
    "sigur": "periculos",
    "siguranță": "pericol",
    "monotonie": "diferență",
    "sănătate psihică": "nebunie",
    "satisfacţie": "nemulţumire",
    "cimbru": "grețos",
    "raritate": "abundenţă",
    "științific": "neştiinţific",
    "scrupulos": "lipsit de scrupule",
    "secundar": "primar",
    "securitate": "nesiguranță",
    "segregare": "integrare",
    "egoist": "altruist",
    "vinde": "a cumpara",
    "senior": "junior",
    "separa": "comun",
    "separare": "uniune",
    "septic": "antiseptic",
    "serviciu": "deserviciu",
    "stabilit": "nelocuit",
    "ascuţi": "aplatiza",
    "mic de statura": "înalt",
    "scurta": "prelungi",
    "spectacol": "ascunde",
    "se contracta": "întinde",
    "latură": "fund",
    "top": "fund",
    "semnificaţie": "inconsistență",
    "semnificativ": "nesemnificativ",
    "asemănător": "diferit",
    "simplifica": "complica",
    "singur": "multiplu",
    "singular": "plural",
    "chiuvetă": "sursă",
    "soră": "frate",
    "dormi": "trezi",
    "încet": "repede",
    "mic": "mare",
    "finete": "rugozitate",
    "moliciune": "acuitate",
    "soliditate": "porozitate",
    "solubil": "insolubil",
    "solvabilitate": "insolvabilitate",
    "solvent": "insolvabil",
    "fiu": "fiică",
    "întristare": "bucurie",
    "vorbit": "scris",
    "nescris": "scris",
    "sporadic": "continuu",
    "răspândire": "aduna",
    "pătrat": "rundă",
    "stabilitate": "instabilitate",
    "grajd": "instabil",
    "stand": "randament",
    "start": "stop",
    "stator": "rotor",
    "stau": "mișcare",
    "constant": "inconstant",
    "abrupt": "treptat",
    "brusc": "treptat",
    "steril": "fertil",
    "înțepeni": "slăbi",
    "zgârcit": "generos",
    "furtunos": "calm",
    "drept": "curb",
    "îndrepta": "îndoire",
    "putere": "slăbiciune",
    "întinde": "se contracta",
    "tare": "slab",
    "studio": "locație",
    "prostie": "inteligență",
    "subiectiv": "obiectiv",
    "subordonat": "dominant",
    "ulterior": "antecedente",
    "substantiv": "adjectiv",
    "scădere": "plus",
    "reușind": "precedent",
    "succes": "eșec",
    "de succes": "fără succes",
    "sucomba": "supravieţui",
    "suferi": "se bucura",
    "suficienta": "insuficienţă",
    "suficient": "insuficient",
    "sufix": "prefix",
    "răsărit": "apus de soare",
    "apus de soare": "răsărit",
    "superior": "inferior",
    "superioritate": "inferioritate",
    "livra": "cerere",
    "sprijinit": "neacceptat",
    "suprafaţă": "deasupra",
    "predare": "a rezista",
    "supravieţui": "sucomba",
    "dulce": "acru",
    "umed": "uscat",
    "îndulci": "acru",
    "simetrie": "asimetrie",
    "simpatic": "unsympathetic",
    "sinergică": "antagonic",
    "sinteză": "analiză",
    "sintetic": "analitic",
    "încetineală": "punctualitate",
    "gustos": "insipid",
    "insipid": "gustos",
    "delicat, fraged": "greu",
    "încordat": "relaxat",
    "terminal": "intermediar",
    "teismului": "ateism",
    "teoretic": "empiric",
    "însetat": "flămând",
    "gospodar": "risipitor",
    "maree": "reflux",
    "cravată": "dezlega",
    "timid": "îndrăzneţ",
    "timiditate": "îndrăzneală",
    "toleranţă": "intoleranţă",
    "tolerant": "intolerant",
    "dințat": "ştirb",
    "ştirb": "dințat",
    "atins": "neatins",
    "greu": "delicat, fraged",
    "maleabil": "intratabil",
    "tragedie": "comedie",
    "dresat": "neinstruit",
    "încredere": "neîncredere",
    "adevăr": "falsitate",
    "urâţenie": "frumuseţe",
    "urât": "frumoasa",
    "inacceptabil": "acceptabil",
    "nerecunoscut": "recunoscut",
    "neschimbat": "schimbat",
    "neînarmat": "armat",
    "neautorizat": "autorizat",
    "dezechilibrat": "echilibrat",
    "necredinţă": "credință",
    "nelegat": "legat",
    "incasabil": "casant",
    "neîntrerupt": "spart",
    "incertitudine": "certitudine",
    "unchi": "mătuşă",
    "neobișnuit": "ca de obicei",
    "indiferent": "îngrijorat",
    "neconfirmat": "confirmat",
    "neconectat": "conectat",
    "inconştienţă": "constiinta",
    "neconstituțional": "constituţional",
    "neconvențional": "convenţional",
    "neconvins": "convins",
    "descoperi": "acoperi",
    "netăiat": "a taia",
    "nedefinit": "definit",
    "subestima": "exagera",
    "indezirabil": "de dorit",
    "necultivat": "educat",
    "neechivoc": "echivoc",
    "fără evenimente importante": "bogat în evenimente",
    "neașteptat": "așteptat",
    "necredincios": "credincios",
    "necunoscut": "familiar",
    "nefavorabil": "favorabil",
    "desfășura": "plia",
    "neiertat": "iertător",
    "nefericit": "fericit",
    "nerecunoscător": "recunoscător",
    "nesănătos": "sănătos",
    "nesfânt": "sfânt",
    "neimportant": "important",
    "neamenajat": "îmbunătățit",
    "neinformat": "informat",
    "nelocuit": "stabilit",
    "ininteligibil": "inteligibil",
    "neintenționate": "destinate",
    "fara intentie": "intentionat",
    "dezinteresați": "interesat",
    "neinteresant": "interesant",
    "uniune": "separare",
    "unitar": "federal",
    "unit": "împărțit",
    "aspru": "drăguț",
    "nelimitat": "limitat",
    "descuia": "blocare",
    "ghinionist": "norocos",
    "nemarcate": "marcat",
    "necăsătorit": "căsătorit",
    "demasca": "masca",
    "neocupat": "ocupat",
    "neoficial": "oficial",
    "fără opoziție": "opus",
    "neortodox": "ortodox",
    "despacheta": "ambalaj",
    "neplăcut": "placut",
    "nepopular": "popular",
    "nepregătit": "pregătit",
    "neproductiv": "productiv",
    "neprotejat": "protejat",
    "nepublicat": "publicat",
    "necontestat": "discutabil",
    "nerealiste": "realist",
    "nereglementat": "reglementate",
    "fără legătură": "legate de",
    "nedemn de încredere": "de încredere",
    "nestăpânit": "reținut",
    "fără restricții": "restrâns",
    "grețos": "cimbru",
    "neştiinţific": "științific",
    "lipsit de scrupule": "scrupulos",
    "altruist": "egoist",
    "instabil": "grajd",
    "inconstant": "constant",
    "fără succes": "de succes",
    "neacceptat": "sprijinit",
    "unsympathetic": "simpatic",
    "dezlega": "cravată",
    "neatins": "atins",
    "neinstruit": "dresat",
    "dezvălui": "voal",
    "nevigilent": "precaut",
    "fără voie": "de bunăvoie",
    "refuzul": "bunăvoință",
    "se desface": "vânt",
    "nevrednic": "vrednic",
    "urban": "rural",
    "ca de obicei": "neobișnuit",
    "valoros": "lipsit de valoare",
    "voal": "dezvălui",
    "verbal": "numeric",
    "victorie": "înfrângere",
    "virtuos": "rău",
    "vizibilitate": "invizibilitate",
    "vizibil": "invizibil",
    "vocal": "instrumental",
    "voluntar": "involuntar",
    "vocală": "consoană",
    "trezi": "dormi",
    "mers pe jos": "călătorie",
    "război": "pace",
    "precaut": "nevigilent",
    "deşeuri": "conserva",
    "risipitor": "gospodar",
    "ceară": "declin",
    "slab": "tare",
    "slăbiciune": "putere",
    "bogatie": "sărăcie",
    "imponderabilă": "cu greutate",
    "cu greutate": "imponderabilă",
    "şoaptă": "strigăt",
    "alb": "negru",
    "în întregime": "parţial",
    "larg": "îngust",
    "largi": "îngust",
    "de bunăvoie": "fără voie",
    "bunăvoință": "refuzul",
    "vânt": "se desface",
    "înţelepciune": "nebunie",
    "înţelept": "prostesc",
    "face griji": "reasigura",
    "lipsit de valoare": "valoros",
    "vrednic": "nevrednic",
    "scris": "nescris",
    "tineri": "în vârstă de",
    "zenit": "nadir",
}



_antonyms = {
    "capacità": "incapacità",
    "anormale": "normale",
    "abolire": "stabilire",
    "assenza": "presenza",
    "assente": "presente",
    "futuro": "passato",
    "assoluto": "parente",
    "astenersi": "consumare",
    "astratto": "calcestruzzo",
    "abbondanza": "scarsità",
    "abbondante": "scarso",
    "accettare": "rifiutare",
    "ammettere": "negare",
    "accettabile": "impraticabile",
    "accettazione": "rifiuto",
    "accessibile": "inaccessibile",
    "preciso": "impreciso",
    "riconosciuto": "non riconosciuto",
    "conoscenza": "sconosciuto",
    "atto": "ritornello",
    "azione": "inattività",
    "attivo": "silenzioso",
    "esistente": "inesistente",
    "rumoroso": "silenzioso",
    "attività": "inattività",
    "effettivo": "potenziale",
    "inserisci": "sottrarre",
    "aggiunta": "sottrazione",
    "adeguato": "insufficiente",
    "aggettivo": "sostanziale",
    "ammissibile": "inammissibile",
    "adulto": "giovanile",
    "avanzare": "recedere",
    "avanti": "indietro",
    "davanti": "posteriore",
    "virare": "indietro",
    "vantaggio": "svantaggio",
    "affermazione": "inversione",
    "affermativa": "negativo",
    "neutro": "femminile",
    "a poppa": "prua, testa",
    "età": "ringiovanire",
    "anziano": "junior",
    "agitazione": "quiete",
    "essere d'accordo": "disaccordo",
    "piacevole": "sgradevole",
    "accordo": "disaccordo",
    "alterato": "inalterato",
    "alternato": "di fronte",
    "dilettante": "professionale",
    "ambiguo": "non ambiguo",
    "amichevole": "ostile",
    "anfibio": "terrestre",
    "anale": "orale",
    "analogo": "omologo",
    "analisi": "sintesi",
    "analitico": "sintetico",
    "antenato": "discendente",
    "angolare": "arrotondato",
    "animare": "inanimato",
    "risposta": "domanda",
    "antagonistico": "sinergico",
    "antecedente": "successivo",
    "anteriore": "posteriore",
    "antisettico": "settico",
    "aspetto": "scomparsa",
    "apprezzamento": "ammortamento",
    "approvazione": "disapprovazione",
    "approvare": "disapprovare",
    "acquatico": "anfibio",
    "terrestre": "celeste",
    "acquoso": "igneo",
    "braccio": "disarmare",
    "armato": "disarmato",
    "arrivo": "partire",
    "ascendere": "scendere",
    "salita": "discesa",
    "addormentato": "sveglio",
    "assenso": "dissenso",
    "asimmetria": "simmetria",
    "ateismo": "teismo",
    "allegare": "distaccare",
    "attacco": "difendere",
    "perseguire": "difendere",
    "attenzione": "disattenzione",
    "attrazione": "repulsione",
    "udibile": "impercettibile",
    "aumento": "diminuzione",
    "zia": "zio",
    "autorizzato": "non autorizzato",
    "automatico": "manuale",
    "evitare": "affrontare",
    "sveglio": "addormentato",
    "indietro": "virare",
    "recedere": "avanzare",
    "posteriore": "anteriore",
    "sfondo": "primo piano",
    "arretrato": "inoltrare",
    "inverso": "diritto",
    "cattivo": "bene",
    "il male": "bene",
    "cattiveria": "bontà",
    "equilibrato": "squilibrato",
    "orso": "toro",
    "bellissimo": "brutta",
    "bellezza": "bruttezza",
    "inizio": "stop",
    "presto": "in ritardo",
    "credenza": "incredulità",
    "piegare": "spiegare",
    "benigno": "maligno",
    "grande": "piccolo",
    "nascita": "morte",
    "bisessuale": "omosessuale",
    "nero": "bianca",
    "benedire": "maledizione",
    "benedetto": "maledetto",
    "esangue": "sanguinoso",
    "sanguinoso": "esangue",
    "sfocatura": "messa a fuoco",
    "bollire": "congelare",
    "grassetto": "timido",
    "audacia": "timidezza",
    "prendere in prestito": "prestare",
    "mutuatario": "prestatore",
    "parte inferiore": "superiore",
    "limite": "unbound",
    "ragazzo": "ragazza",
    "boicottare": "patrocinare",
    "rompere": "riparazione",
    "fragile": "infrangibile",
    "rallegrare": "lamentarsi",
    "alleggerire": "scurire",
    "rotto": "ininterrotto",
    "fratello": "sorella",
    "toro": "orso",
    "occupato": "disoccupato",
    "lavoro": "inattivo",
    "acquistare": "vendere",
    "calma": "tempestoso",
    "quiete": "agitazione",
    "capace": "incapace",
    "contanti": "credito",
    "addebito": "credito",
    "centro": "sinistra",
    "cerebrale": "emotivo",
    "certezza": "incertezza",
    "modificare": "restare",
    "partire": "arrivo",
    "mossa": "restare",
    "variabile": "immutabile",
    "cambiato": "immutato",
    "carica": "scarico",
    "arruolare": "scarico",
    "a buon mercato": "costoso",
    "allegro": "deprimente",
    "bambino": "genitore",
    "civile": "militare",
    "richiesta": "pegno",
    "chiarezza": "opacità",
    "prominenza": "oscurità",
    "trasparenza": "opacità",
    "pulito": "immondo",
    "clero": "laicato",
    "ecclesiastico": "laico",
    "vicino": "aperto",
    "chiuso": "aperto",
    "vicinanza": "apertura",
    "costiero": "nell'entroterra",
    "coerente": "incoerente",
    "freddo": "calore",
    "collaterale": "diretto",
    "commedia": "tragedia",
    "comfort": "sconforto",
    "comune": "raro",
    "compatibile": "incompatibile",
    "competenza": "incompetenza",
    "competente": "incompetente",
    "concorrenza": "cooperazione",
    "lamentarsi": "rallegrare",
    "completezza": "incompletezza",
    "complesso": "semplice",
    "composto": "semplice",
    "conforme": "provocatorio",
    "complicato": "semplificare",
    "concavo": "convesso",
    "presunzione": "umiltà",
    "orgoglio": "umiltà",
    "concentrazione": "distribuzione",
    "concentrico": "eccentrico",
    "concezione": "idea sbagliata",
    "ha riguardato": "indifferente",
    "calcestruzzo": "astratto",
    "confermato": "non confermato",
    "affrontare": "evitare",
    "congiuntivo": "disgiuntivo",
    "collegare": "disconnect",
    "collegato": "non connesso",
    "coscienza": "incoscienza",
    "prudente": "imprudente",
    "conservare": "rifiuto",
    "premuroso": "sconsiderato",
    "consistenza": "incoerenza",
    "consonante": "vocale",
    "cospicuo": "non appariscente",
    "costituzionale": "anticostituzionale",
    "consumare": "astenersi",
    "soddisfare": "malcontento",
    "continuo": "discontinuo",
    "continuazione": "interruzione",
    "continua": "interrompere",
    "continuità": "discontinuità",
    "contrarre": "espandere",
    "contratto": "allargato",
    "contrazione": "espansione",
    "conveniente": "sconveniente",
    "convenzionale": "non convenzionale",
    "convergere": "divergere",
    "convergenza": "divergenza",
    "convergente": "divergente",
    "convesso": "concavo",
    "convinto": "poco convinta",
    "cooperazione": "concorrenza",
    "cosmopolita": "provinciale",
    "coraggio": "viltà",
    "copertina": "scoprire",
    "nascosto": "evidente",
    "viltà": "coraggio",
    "credito": "addebito",
    "creditore": "debitore",
    "criticare": "lode",
    "piangere": "ridere",
    "curabile": "incurabile",
    "maledizione": "benedire",
    "maledetto": "benedetto",
    "curvo": "dritto",
    "tagliare": "integrale",
    "pericolo": "sicurezza",
    "pericoloso": "sicuro",
    "buio": "leggerezza",
    "scurire": "alleggerire",
    "pesantezza": "leggerezza",
    "figlia": "figlio",
    "giorno": "notte",
    "sordo": "udito",
    "morte": "nascita",
    "debitore": "creditore",
    "decenza": "indecenza",
    "decente": "indecente",
    "deciduo": "sempreverde",
    "decisione": "indecisione",
    "decisivo": "indeciso",
    "declino": "cera",
    "diminuire": "aumentare",
    "diminuita": "è aumentato",
    "diminuzione": "aumento",
    "la sconfitta": "vittoria",
    "difendere": "perseguire",
    "imputato": "attore",
    "difesa": "accusa",
    "difensiva": "offensivo",
    "provocatorio": "conforme",
    "disavanzo": "condurre",
    "definito": "non definito",
    "deflazione": "inflazione",
    "ritardo": "puntualità",
    "soffermarsi": "corsa",
    "richiesta": "fornitura",
    "negare": "ammettere",
    "rifiutare": "accettare",
    "dipendente": "indipendente",
    "depositare": "ritirarsi",
    "ammortamento": "apprezzamento",
    "deprimente": "allegro",
    "scendere": "ascendere",
    "discendente": "antenato",
    "discesa": "salita",
    "descrittivo": "prescrittivo",
    "auspicabile": "indesiderabile",
    "disperazione": "speranza",
    "disperato": "speranza",
    "distrutto": "conservato",
    "distaccare": "allegare",
    "devoluzione": "evoluzione",
    "differire": "pari",
    "ineguale": "pari",
    "differenza": "monotonia",
    "difficile": "tenero",
    "inquieto": "facile",
    "difficoltà": "alleviare",
    "diligente": "negligente",
    "diluizione": "concentrazione",
    "distribuzione": "concentrazione",
    "sporco": "pulito",
    "immondo": "pulito",
    "disattivare": "abilitare",
    "svantaggio": "vantaggio",
    "disaccordo": "accordo",
    "sgradevole": "salato",
    "scomparsa": "aspetto",
    "disapprovazione": "approvazione",
    "disapprovare": "approvare",
    "disarmare": "braccio",
    "scarico": "arruolare",
    "disconoscere": "richiesta",
    "pegno": "richiesta",
    "sconforto": "comfort",
    "disconnect": "collegare",
    "malcontento": "soddisfare",
    "interruzione": "continuazione",
    "interrompere": "continua",
    "discontinuità": "continuità",
    "discontinuo": "continuo",
    "scoraggiare": "incoraggiare",
    "scoraggiamento": "incoraggiamento",
    "disimpegnare": "impegnare",
    "disonesto": "onesto",
    "disonestà": "onestà",
    "disonore": "onore",
    "disinfettare": "infettare",
    "disintegrare": "integrare",
    "disgiuntivo": "congiuntivo",
    "antipatia": "simpatia",
    "sloggiare": "casetta",
    "disobbedienza": "obbedienza",
    "disobbediente": "obbediente",
    "disobbedire": "obbedire",
    "disturbo": "ordine",
    "disordinato": "ordinato",
    "disorganizzato": "organizzato",
    "scontento": "contento",
    "confutare": "dimostrare",
    "squalificare": "qualificarsi",
    "sconveniente": "conveniente",
    "discredito": "reputazione",
    "mancanza di rispetto": "rispetto",
    "irrispettoso": "rispettoso",
    "insoddisfazione": "soddisfazione",
    "dissenso": "assenso",
    "disservizio": "servizio",
    "dissimile": "simile",
    "dissonanza": "armonia",
    "dissuadere": "persuadere",
    "distale": "prossimale",
    "lontano": "vicino",
    "aperto": "chiuso",
    "distinguibile": "indistinguibile",
    "diffidenza": "fiducia",
    "diurno": "notturno",
    "divergere": "convergere",
    "divergenza": "convergenza",
    "divergente": "convergente",
    "dividere": "unire",
    "singolarmente": "moltiplicare",
    "diviso": "unito",
    "divisibile": "indivisibile",
    "domestico": "straniero",
    "nativo": "straniero",
    "dominante": "subordinare",
    "inattivo": "lavoro",
    "estinto": "esistente",
    "passivo": "attivo",
    "silenzioso": "rumoroso",
    "doppio": "singolo",
    "multiplo": "singolo",
    "colomba": "falco",
    "drammatico": "lirica",
    "asciutto": "bagnato",
    "aspro": "addolcire",
    "dovuto": "indebito",
    "noioso": "affilare",
    "appiattire": "affilare",
    "sta morendo": "nascente",
    "alleviare": "difficoltà",
    "facile": "inquieto",
    "riflusso": "marea",
    "eccentrico": "concentrico",
    "educato": "incolto",
    "efficace": "inefficace",
    "efficienza": "inefficienza",
    "efficiente": "inefficiente",
    "uscita": "ingresso",
    "elastico": "non elastico",
    "idoneo": "ineleggibile",
    "emotivo": "cerebrale",
    "empirico": "teorico",
    "vuoto": "pieno",
    "magro": "addensare",
    "abilitare": "disattivare",
    "incoraggiare": "scoraggiare",
    "incoraggiamento": "scoraggiamento",
    "fine": "inizio",
    "mezzo": "presto",
    "endemico": "cosmopolita",
    "provinciale": "cosmopolita",
    "energico": "letargico",
    "imporre": "esonerare",
    "impegnare": "disimpegnare",
    "godere": "soffrire",
    "accedere": "uscita",
    "pari": "ineguale",
    "uguaglianza": "disuguaglianza",
    "equatoriale": "polare",
    "equo": "non equo",
    "equivoco": "inequivocabile",
    "cancellare": "disco",
    "stabilire": "abolire",
    "movimentato": "non movimentato",
    "sempreverde": "deciduo",
    "evoluzione": "devoluzione",
    "esclusione": "inclusione",
    "esonerare": "imporre",
    "esalare": "inalare",
    "uscita": "accedere",
    "espandere": "contrarre",
    "allargato": "contratto",
    "espansione": "contrazione",
    "previsto": "inaspettato",
    "costoso": "a buon mercato",
    "esperto": "inesperto",
    "esportare": "importare",
    "esprimere": "locale",
    "generale": "specifica",
    "nazionale": "internazionale",
    "estensione": "flessione",
    "esterno": "interno",
    "esternamente": "internamente",
    "spegnere": "infiammare",
    "fuori dell'università": "intramurale",
    "straordinario": "ordinario",
    "estrinseco": "intrinseco",
    "in mancanza di": "passaggio",
    "in esecuzione": "in piedi",
    "fallimento": "successo",
    "giusto": "sleale",
    "fedele": "infedele",
    "autunno": "salire",
    "impostato": "salire",
    "fallibile": "infallibile",
    "caduta": "crescente",
    "falsità": "verità",
    "fama": "infamia",
    "familiare": "sconosciuto",
    "fantasia": "pianura",
    "grasso": "magro",
    "pieno": "vuoto",
    "di spessore": "magro",
    "addensare": "magro",
    "padre": "madre",
    "fauna": "flora",
    "favorevole": "sfavorevole",
    "federale": "unitario",
    "femmina": "maschio",
    "femminile": "neutro",
    "femminilità": "mascolinità",
    "fertile": "sterile",
    "fedeltà": "infedeltà",
    "figura": "terra",
    "riempire": "vuoto",
    "trova": "perdere",
    "finire": "inizio",
    "stop": "inizio",
    "finito": "infinito",
    "fuoco": "assumere",
    "flessione": "estensione",
    "galleggiante": "lavello",
    "fonte": "lavello",
    "flora": "fauna",
    "messa a fuoco": "sfocatura",
    "nemico": "amico",
    "seguire": "precedere",
    "avere successo": "precedere",
    "seguace": "capo",
    "follia": "salute mentale",
    "folle": "sano di mente",
    "piede": "capo",
    "coda": "capo",
    "vietare": "permesso",
    "prua, testa": "a poppa",
    "primo piano": "sfondo",
    "straniero": "nativo",
    "dimenticare": "ricorda",
    "perdonare": "imperdonabile",
    "formalismo": "imitazione",
    "fortunato": "sfortunato",
    "inoltrare": "inverso",
    "diritto": "inverso",
    "fallo": "giusto",
    "sleale": "giusto",
    "trovato": "perduto",
    "fraterno": "identico",
    "congelare": "bollire",
    "frequente": "infrequente",
    "frequentemente": "non frequentemente",
    "amico": "nemico",
    "capo": "seguace",
    "pienezza": "vuoto",
    "funzionale": "biologico",
    "inorganico": "biologico",
    "guadagno": "perdita",
    "gassoso": "solido",
    "cavo": "solido",
    "raccogliere": "diffusione",
    "generalità": "particolarità",
    "generoso": "avaro",
    "ragazza": "ragazzo",
    "bene": "il male",
    "bontà": "cattiveria",
    "graduale": "improvviso",
    "grato": "ingrato",
    "maggiore": "minore",
    "verde": "maturo",
    "schifoso": "netto",
    "terra": "figura",
    "colpa": "innocenza",
    "colpevole": "innocente",
    "felicemente": "purtroppo",
    "felicità": "infelicità",
    "contento": "scontento",
    "durezza": "morbidezza",
    "rumorosità": "morbidezza",
    "nitidezza": "morbidezza",
    "armonia": "dissonanza",
    "odiare": "amore",
    "odioso": "amabile",
    "falco": "colomba",
    "salutare": "malsano",
    "udito": "sordo",
    "calore": "freddo",
    "celeste": "terrestre",
    "eterogeneità": "omogeneità",
    "nascondere": "mostrare",
    "assumere": "fuoco",
    "colpire": "perdere",
    "santo": "empio",
    "omogeneità": "eterogeneità",
    "omologo": "analogo",
    "omosessuale": "bisessuale",
    "onesto": "disonesto",
    "onestà": "disonestà",
    "onore": "disonore",
    "speranza": "disperazione",
    "pieno di speranza": "senza speranza",
    "senza speranza": "pieno di speranza",
    "orizzontale": "verticale",
    "ostile": "amichevole",
    "caldo": "freddo",
    "umile": "orgoglioso",
    "umiltà": "orgoglio",
    "affamato": "assetato",
    "identico": "fraterno",
    "igneo": "acquoso",
    "infiammare": "spegnere",
    "ignorare": "avviso",
    "illegale": "legale",
    "illegalità": "legalità",
    "illeggibile": "leggibile",
    "illogico": "logico",
    "imitazione": "formalismo",
    "immateriale": "materiale",
    "immaturità": "scadenza",
    "incommensurabile": "misurabile",
    "immorale": "morale",
    "immoralità": "moralità",
    "immortale": "mortale",
    "immortalità": "mortalità",
    "immutabile": "variabile",
    "imparzialità": "parzialità",
    "impraticabile": "accettabile",
    "impazienza": "pazienza",
    "impaziente": "paziente",
    "impercettibile": "udibile",
    "imperfezione": "perfezione",
    "impermeabile": "permeabile",
    "inammissibile": "ammissibile",
    "impersonale": "personale",
    "scortese": "genere",
    "importare": "esportare",
    "importante": "irrilevante",
    "impossibilità": "possibilità",
    "impotente": "potente",
    "improbabile": "probabile",
    "migliorata": "unimproved",
    "miglioramento": "declino",
    "imprudente": "prudente",
    "impurità": "purezza",
    "incapacità": "capacità",
    "inaccessibile": "accessibile",
    "impreciso": "preciso",
    "inattività": "attività",
    "insufficiente": "sufficiente",
    "inanimato": "animare",
    "disattenzione": "attenzione",
    "incapace": "capace",
    "inclinato": "orizzontale",
    "verticale": "orizzontale",
    "inclusione": "esclusione",
    "incoerente": "coerente",
    "incompatibile": "compatibile",
    "incompetenza": "competenza",
    "incompetente": "competente",
    "incompletezza": "completezza",
    "sconsiderato": "premuroso",
    "incoerenza": "consistenza",
    "non appariscente": "cospicuo",
    "aumentare": "inferiore",
    "è aumentato": "diminuita",
    "incremento": "diminuzione",
    "incurabile": "curabile",
    "indecenza": "decenza",
    "indecente": "decente",
    "indecisione": "decisione",
    "indeciso": "decisivo",
    "indipendente": "dipendente",
    "indistinguibile": "distinguibile",
    "indivisibile": "divisibile",
    "interno": "esterno",
    "inefficace": "efficace",
    "inefficienza": "efficienza",
    "inefficiente": "efficiente",
    "non elastico": "elastico",
    "ineleggibile": "idoneo",
    "disuguaglianza": "uguaglianza",
    "non equo": "equo",
    "inesperto": "esperto",
    "infallibile": "fallibile",
    "infamia": "fama",
    "infettare": "disinfettare",
    "inferiore": "aumentare",
    "inferiorità": "superiorità",
    "infedeltà": "fedeltà",
    "infinito": "finito",
    "inflazione": "deflazione",
    "informato": "disinformato",
    "infrequente": "frequente",
    "non frequentemente": "frequentemente",
    "ingresso": "uscita",
    "abitato": "disabitato",
    "inalare": "esalare",
    "ingiustizia": "giustizia",
    "nell'entroterra": "costiero",
    "innocenza": "colpa",
    "innocente": "colpevole",
    "innocuo": "nocivo",
    "non operante": "operativo",
    "insicurezza": "sicurezza",
    "piccolezza": "significato",
    "insignificante": "significativo",
    "insolubile": "solubile",
    "insolvenza": "solvibilità",
    "insolvente": "solvente",
    "instabilità": "stabilità",
    "strumentale": "vocale",
    "insufficienza": "sufficienza",
    "insufficientemente": "sufficientemente",
    "integrare": "disintegrare",
    "integrazione": "segregazione",
    "intelligenza": "stupidità",
    "intelligibile": "incomprensibile",
    "destinato": "non inteso",
    "apposta": "involontariamente",
    "interessato": "indifferente",
    "interessante": "non interessante",
    "intermedio": "terminale",
    "internamente": "esternamente",
    "internazionale": "nazionale",
    "locale": "generale",
    "intolleranza": "tolleranza",
    "intollerante": "tollerante",
    "intrattabile": "trattabile",
    "intramurale": "fuori dell'università",
    "intrinseco": "estrinseco",
    "invisibilità": "visibilità",
    "invisibile": "visibile",
    "involontario": "volontario",
    "irrazionale": "razionale",
    "irregolare": "regolare",
    "irregolarità": "regolarità",
    "non pertinente": "pertinente",
    "irresponsabile": "responsabile",
    "irriverente": "riverente",
    "problema": "richiamare",
    "comune": "separato",
    "gioia": "tristezza",
    "gioioso": "dolente",
    "junior": "anziano",
    "giustizia": "ingiustizia",
    "giovanile": "adulto",
    "contadino irlandese": "contadino irlandese",
    "genere": "scortese",
    "re": "regina",
    "laicato": "clero",
    "in ritardo": "presto",
    "ridere": "piangere",
    "legale": "illegale",
    "negligente": "diligente",
    "rilassato": "teso",
    "laico": "ecclesiastico",
    "condurre": "disavanzo",
    "sinistra": "centro",
    "legalità": "illegalità",
    "legalizzare": "fuorilegge",
    "leggibile": "illeggibile",
    "prestare": "prendere in prestito",
    "prestatore": "mutuatario",
    "allungare": "contrarsi",
    "minore": "maggiore",
    "letargico": "energico",
    "livello": "aumentare",
    "liberale": "prudente",
    "menzogna": "stare in piedi",
    "dare la precedenza": "stare in piedi",
    "leggero": "buio",
    "leggerezza": "pesantezza",
    "simpatia": "antipatia",
    "limitato": "illimitato",
    "diretto": "collaterale",
    "liquido": "gassoso",
    "solido": "cavo",
    "specifica": "generale",
    "posizione": "studio",
    "serratura": "sbloccare",
    "casetta": "sloggiare",
    "logico": "illogico",
    "lungo": "corto",
    "alto": "superficie",
    "allentare": "irrigidirsi",
    "perdere": "trova",
    "perdita": "guadagno",
    "perduto": "trovato",
    "amabile": "odioso",
    "amore": "odiare",
    "lirica": "drammatico",
    "maggioranza": "minoranza",
    "rendere": "rompere",
    "riparazione": "rompere",
    "maschio": "femmina",
    "maligno": "benigno",
    "manuale": "automatico",
    "segnato": "non marcato",
    "sposato": "celibe",
    "maschile": "femminile",
    "mascolinità": "femminilità",
    "maschera": "smascherare",
    "materiale": "immateriale",
    "materno": "paterno",
    "scadenza": "immaturità",
    "massimo": "minimo",
    "misurabile": "incommensurabile",
    "mentale": "fisico",
    "misericordioso": "spietato",
    "spietato": "misericordioso",
    "militare": "civile",
    "mente": "dimenticare",
    "ricorda": "dimenticare",
    "minimo": "massimo",
    "minoranza": "maggioranza",
    "idea sbagliata": "concezione",
    "perdere": "colpire",
    "molare": "molecolare",
    "molecolare": "molare",
    "morale": "immorale",
    "moralità": "immoralità",
    "mortale": "immortale",
    "mortalità": "immortalità",
    "madre": "padre",
    "moltiplicare": "singolarmente",
    "unire": "dividere",
    "mutevole": "immutabile",
    "nadir": "zenit",
    "stretto": "allargare",
    "nascente": "sta morendo",
    "negativo": "neutro",
    "nipote": "nipote",
    "netto": "schifoso",
    "notte": "giorno",
    "notturno": "diurno",
    "nominale": "vero",
    "irreale": "vero",
    "inesistente": "esistente",
    "normale": "anormale",
    "avviso": "ignorare",
    "nocivo": "innocuo",
    "numerico": "verbale",
    "obbedienza": "disobbedienza",
    "obbediente": "disobbediente",
    "obbedire": "disobbedire",
    "obbiettivo": "soggettivo",
    "obbligatorio": "opzionale",
    "obliquo": "perpendicolare",
    "oscurità": "prominenza",
    "opacità": "trasparenza",
    "offesa": "difesa",
    "accusa": "difesa",
    "offensivo": "difensiva",
    "ufficiale": "non ufficiale",
    "apertura": "vicinanza",
    "operativo": "non operante",
    "contrario": "incontrastata",
    "di fronte": "alternato",
    "ottimismo": "pessimismo",
    "ottimista": "pessimista",
    "opzionale": "obbligatorio",
    "orale": "anale",
    "ordine": "disturbo",
    "ordinato": "disordinato",
    "ordinario": "straordinario",
    "biologico": "inorganico",
    "organizzato": "disorganizzato",
    "ortodosso": "non ortodosso",
    "all'aperto": "interno",
    "fuorilegge": "legalizzare",
    "sopravvalutare": "sottovalutare",
    "evidente": "nascosto",
    "pacco": "disfare",
    "doloroso": "indolore",
    "indolore": "doloroso",
    "parallelo": "obliquo",
    "perpendicolare": "obliquo",
    "genitore": "bambino",
    "parzialità": "imparzialità",
    "particolarità": "generalità",
    "in parte": "interamente",
    "passaggio": "in esecuzione",
    "in piedi": "in esecuzione",
    "passato": "futuro",
    "presente": "assente",
    "paterno": "materno",
    "pazienza": "impazienza",
    "paziente": "impaziente",
    "patrocinare": "boicottare",
    "pace": "guerra",
    "pena": "ricompensa",
    "percettibile": "impercettibile",
    "perfezione": "imperfezione",
    "permeabile": "impermeabile",
    "permissivo": "preventivo",
    "permesso": "vietare",
    "personale": "impersonale",
    "persuadere": "dissuadere",
    "pessimismo": "ottimismo",
    "pessimista": "ottimista",
    "fisico": "mentale",
    "pianura": "fantasia",
    "attore": "imputato",
    "plurale": "singolare",
    "polare": "equatoriale",
    "gentile": "scortese",
    "popolare": "impopolare",
    "porosità": "solidità",
    "possibilità": "impossibilità",
    "potente": "impotente",
    "potenziale": "effettivo",
    "povertà": "ricchezza",
    "lode": "criticare",
    "precedere": "avere successo",
    "precedente": "successivo",
    "prefisso": "suffisso",
    "preparazione": "risoluzione",
    "preparato": "impreparato",
    "prescrittivo": "descrittivo",
    "presenza": "assenza",
    "conservato": "distrutto",
    "preventivo": "permissivo",
    "primario": "secondario",
    "privato": "pubblico",
    "privatamente": "pubblicamente",
    "probabile": "improbabile",
    "produttivo": "improduttivo",
    "profano": "sacro",
    "professionale": "dilettante",
    "progresso": "regredire",
    "progressivo": "regressivo",
    "prospettiva": "retrospettiva",
    "protetta": "indifeso",
    "orgoglioso": "umile",
    "dimostrare": "confutare",
    "prossimale": "distale",
    "prossimità": "finale",
    "pubblico": "privato",
    "pubblicamente": "privatamente",
    "pubblicato": "inedito",
    "tirare": "spingere",
    "puntualità": "ritardo",
    "epurazione": "riabilitare",
    "purezza": "impurità",
    "spingere": "tirare",
    "qualificarsi": "squalificare",
    "regina": "re",
    "domanda": "risposta",
    "discutibile": "indiscutibile",
    "velocemente": "lentamente",
    "razionale": "irrazionale",
    "vero": "irreale",
    "realistico": "non realistico",
    "rassicurare": "preoccupazione",
    "richiamare": "problema",
    "disco": "cancellare",
    "ritornello": "atto",
    "rifiuto": "conservare",
    "regredire": "progresso",
    "regressivo": "progressivo",
    "regolare": "irregolare",
    "regolarità": "irregolarità",
    "regolata": "non regolamentata",
    "riabilitare": "epurazione",
    "ringiovanire": "età",
    "relazionato": "estraneo",
    "parente": "assoluto",
    "pertinente": "non pertinente",
    "affidabile": "inaffidabile",
    "religioso": "secolare",
    "repulsione": "attrazione",
    "rispettabile": "sconveniente",
    "reputazione": "discredito",
    "resistere": "resa",
    "risoluzione": "preparazione",
    "rispetto": "mancanza di rispetto",
    "rispettoso": "irrispettoso",
    "responsabile": "irresponsabile",
    "contenuto": "sfrenato",
    "retrospettiva": "prospettiva",
    "riverente": "irriverente",
    "inversione": "affermazione",
    "ricompensa": "pena",
    "cavalcata": "camminare",
    "maturo": "verde",
    "salire": "impostato",
    "crescente": "caduta",
    "rotore": "statore",
    "rugosità": "levigatezza",
    "il giro": "piazza",
    "arrotondato": "angolare",
    "rurale": "urbano",
    "corsa": "soffermarsi",
    "sacro": "profano",
    "purtroppo": "felicemente",
    "tristezza": "gioia",
    "infelicità": "felicità",
    "sicuro": "pericoloso",
    "sicurezza": "insicurezza",
    "monotonia": "differenza",
    "sano di mente": "folle",
    "salute mentale": "follia",
    "soddisfazione": "insoddisfazione",
    "salato": "sgradevole",
    "scarso": "abbondante",
    "scarsità": "abbondanza",
    "scientifico": "non scientifico",
    "scrupoloso": "senza scrupoli",
    "secondario": "primario",
    "secolare": "religioso",
    "segregazione": "integrazione",
    "egoista": "altruista",
    "vendere": "acquistare",
    "separato": "comune",
    "separazione": "unione",
    "settico": "antisettico",
    "servizio": "disservizio",
    "sistemato": "incerto",
    "affilare": "appiattire",
    "corto": "alto",
    "accorciare": "allungare",
    "grido": "sussurro",
    "mostrare": "nascondere",
    "contrarsi": "allungare",
    "lato": "parte inferiore",
    "superiore": "inferiore",
    "significato": "piccolezza",
    "significativo": "insignificante",
    "simile": "dissimile",
    "semplice": "composto",
    "semplificare": "complicato",
    "singolo": "multiplo",
    "singolare": "plurale",
    "lavello": "fonte",
    "sorella": "fratello",
    "dormire": "svegliare",
    "lentamente": "velocemente",
    "piccolo": "grande",
    "levigatezza": "rugosità",
    "morbidezza": "nitidezza",
    "solidità": "porosità",
    "solubile": "insolubile",
    "solvibilità": "insolvenza",
    "solvente": "insolvente",
    "figlio": "figlia",
    "dolente": "gioioso",
    "verbale": "numerico",
    "non scritto": "scritto",
    "sporadico": "continuo",
    "diffusione": "raccogliere",
    "piazza": "il giro",
    "stabilità": "instabilità",
    "stabile": "instabile",
    "stare in piedi": "dare la precedenza",
    "statore": "rotore",
    "restare": "mossa",
    "costante": "instabile",
    "ripido": "graduale",
    "improvviso": "graduale",
    "sterile": "fertile",
    "irrigidirsi": "allentare",
    "avaro": "generoso",
    "tempestoso": "calma",
    "dritto": "curvo",
    "raddrizzare": "piegare",
    "sconosciuto": "familiare",
    "forza": "debolezza",
    "fortemente": "debolmente",
    "studio": "posizione",
    "stupidità": "intelligenza",
    "soggettivo": "obbiettivo",
    "subordinare": "dominante",
    "successivo": "precedente",
    "sostanziale": "aggettivo",
    "sottrarre": "inserisci",
    "sottrazione": "aggiunta",
    "successo": "fallimento",
    "riuscito": "senza esito",
    "soccombere": "sopravvivere",
    "soffrire": "godere",
    "sufficienza": "insufficienza",
    "sufficiente": "insufficiente",
    "sufficientemente": "insufficientemente",
    "suffisso": "prefisso",
    "alba": "tramonto",
    "tramonto": "alba",
    "superiorità": "inferiorità",
    "fornitura": "richiesta",
    "supportato": "supportato",
    "superficie": "alto",
    "resa": "resistere",
    "sopravvivere": "soccombere",
    "dolce": "aspro",
    "bagnato": "asciutto",
    "addolcire": "aspro",
    "simmetria": "asimmetria",
    "comprensivo": "antipatico",
    "sinergico": "antagonistico",
    "sintesi": "analisi",
    "sintetico": "analitico",
    "raffinato": "insapore",
    "gustoso": "insapore",
    "insapore": "gustoso",
    "tenero": "difficile",
    "teso": "rilassato",
    "terminale": "intermedio",
    "teismo": "ateismo",
    "teorico": "empirico",
    "assetato": "affamato",
    "riflessivo": "senza pensieri",
    "senza pensieri": "riflessivo",
    "parsimonioso": "dispendioso",
    "marea": "riflusso",
    "cravatta": "sciogliere",
    "timido": "grassetto",
    "timidezza": "audacia",
    "tolleranza": "intolleranza",
    "tollerante": "intollerante",
    "dentata": "sdentato",
    "sdentato": "dentata",
    "toccato": "intatto",
    "trattabile": "intrattabile",
    "tragedia": "commedia",
    "allenato": "non addestrato",
    "fiducia": "diffidenza",
    "verità": "falsità",
    "bruttezza": "bellezza",
    "brutta": "bellissimo",
    "finale": "prossimità",
    "inaccettabile": "accettabile",
    "non riconosciuto": "riconosciuto",
    "inalterato": "alterato",
    "non ambiguo": "ambiguo",
    "disarmato": "armato",
    "non autorizzato": "autorizzato",
    "squilibrato": "equilibrato",
    "incredulità": "credenza",
    "unbound": "limite",
    "infrangibile": "fragile",
    "ininterrotto": "rotto",
    "incertezza": "certezza",
    "immutato": "cambiato",
    "zio": "zia",
    "raro": "comune",
    "indifferente": "interessato",
    "non confermato": "confermato",
    "non connesso": "collegato",
    "incoscienza": "coscienza",
    "anticostituzionale": "costituzionale",
    "non convenzionale": "convenzionale",
    "poco convinta": "convinto",
    "scoprire": "copertina",
    "integrale": "tagliare",
    "non definito": "definito",
    "sottovalutare": "sopravvalutare",
    "indesiderabile": "auspicabile",
    "indebito": "dovuto",
    "incolto": "educato",
    "inequivocabile": "equivoco",
    "non movimentato": "movimentato",
    "inaspettato": "previsto",
    "infedele": "fedele",
    "sfavorevole": "favorevole",
    "spiegare": "piegare",
    "imperdonabile": "perdonare",
    "sfortunato": "fortunato",
    "ingrato": "grato",
    "infelice": "contento",
    "malsano": "salutare",
    "empio": "santo",
    "irrilevante": "importante",
    "unimproved": "migliorata",
    "disinformato": "informato",
    "disabitato": "abitato",
    "incomprensibile": "intelligibile",
    "non inteso": "destinato",
    "involontariamente": "apposta",
    "non interessante": "interessante",
    "unione": "separazione",
    "unitario": "federale",
    "unito": "diviso",
    "illimitato": "limitato",
    "sbloccare": "serratura",
    "non marcato": "segnato",
    "celibe": "sposato",
    "smascherare": "maschera",
    "disoccupato": "occupato",
    "non ufficiale": "ufficiale",
    "incontrastata": "contrario",
    "non ortodosso": "ortodosso",
    "disfare": "pacco",
    "impopolare": "popolare",
    "impreparato": "preparato",
    "improduttivo": "produttivo",
    "indifeso": "protetta",
    "inedito": "pubblicato",
    "indiscutibile": "discutibile",
    "non realistico": "realistico",
    "non regolamentata": "regolata",
    "estraneo": "relazionato",
    "inaffidabile": "affidabile",
    "sfrenato": "contenuto",
    "non scientifico": "scientifico",
    "senza scrupoli": "scrupoloso",
    "altruista": "egoista",
    "incerto": "sistemato",
    "instabile": "costante",
    "senza esito": "riuscito",
    "antipatico": "comprensivo",
    "sciogliere": "cravatta",
    "intatto": "toccato",
    "non addestrato": "allenato",
    "insolito": "solito",
    "svelare": "velo",
    "incauto": "diffidente",
    "controvoglia": "volentieri",
    "riluttanza": "buona volontà",
    "rilassarsi": "vento",
    "indegno": "degno",
    "urbano": "rurale",
    "solito": "insolito",
    "prezioso": "senza valore",
    "velo": "svelare",
    "vittoria": "la sconfitta",
    "virtuoso": "malvagio",
    "visibilità": "invisibilità",
    "visibile": "invisibile",
    "vocale": "consonante",
    "volontario": "involontario",
    "svegliare": "dormire",
    "camminare": "cavalcata",
    "guerra": "pace",
    "diffidente": "incauto",
    "dispendioso": "parsimonioso",
    "cera": "declino",
    "debolmente": "fortemente",
    "debolezza": "forza",
    "ricchezza": "povertà",
    "senza peso": "pesante",
    "pesante": "senza peso",
    "sussurro": "grido",
    "bianca": "nero",
    "interamente": "in parte",
    "malvagio": "virtuoso",
    "largo": "stretto",
    "allargare": "stretto",
    "volentieri": "controvoglia",
    "buona volontà": "riluttanza",
    "vento": "rilassarsi",
    "saggezza": "follia",
    "saggio": "folle",
    "ritirarsi": "depositare",
    "preoccupazione": "rassicurare",
    "senza valore": "prezioso",
    "degno": "indegno",
    "scritto": "non scritto",
    "giovane": "anziano",
    "zenit": "nadir",
}
